( cd usr/lib64 ; rm -rf libaudiofile.so )
( cd usr/lib64 ; ln -sf libaudiofile.so.0.0.2 libaudiofile.so )
( cd usr/lib64 ; rm -rf libaudiofile.so.0 )
( cd usr/lib64 ; ln -sf libaudiofile.so.0.0.2 libaudiofile.so.0 )
